@@ -5,14 +5,12 @@
 pub mod metadata;
 pub mod model;
 pub mod repo;
-pub mod scanner;
-pub mod thumbnail;
+pub mod thumbnailer;
 pub mod transcode;
 
 pub use model::Metadata;
 pub use model::Video;
 pub use model::VideoId;
 pub use repo::Repository;
-pub use scanner::Scanner;
-pub use thumbnail::Thumbnailer;
+pub use thumbnailer::VideoThumbnailer;
 pub use transcode::Transcoder;
